@@ -182,8 +182,10 @@ def calcFAS(coreDir, outDir, coreSet, queryID, annoDir, cpus, force):
     if mode == 1 or mode == 3:
         finalPhyloprofile = open('%s/mode23.phyloprofile' % (phyloprofileDir), 'w')
         finalPhyloprofile.write('geneID\tncbiID\torthoID\tFAS_F\tFAS_B\n')
+        finalDomain = open('%s/mode23.domains' % (phyloprofileDir), 'w')
     elif mode == 2:
         finalPhyloprofile = open('%s/mode23.phyloprofile' % (phyloprofileDir), 'a')
+        finalDomain = open('%s/mode23.domains' % (phyloprofileDir), 'a')
     # parse single fdog output
     missing = []
     fdogOutDir = '%s/fcatOutput/%s/%s/fdogOutput' % (outDir, coreSet, queryID)
@@ -220,7 +222,19 @@ def calcFAS(coreDir, outDir, coreSet, queryID, annoDir, cpus, force):
                 for groupID in groups:
                     coreFasDir = '%s/core_orthologs/%s/%s/fas_dir/fasscore_dir' % (coreDir, coreSet, groupID)
                     for fasFile in glob.glob('%s/*.tsv' % coreFasDir):
-                        if not refSpec in fasFile:
+                        if queryID.split('@')[1] == refSpec.split('@')[1]:
+                            if not refSpec in fasFile:
+                                for fLine in readFile(fasFile):
+                                    if refSpec in fLine.split('\t')[0]:
+                                        tmp = fLine.split('\t')
+                                        revFAS = 0
+                                        revFile = '%s/%s.tsv' % (coreFasDir, tmp[0].split('|')[1])
+                                        for revLine in readFile(revFile):
+                                            if tmp[1] == revLine.split('\t')[0]:
+                                                revFAS = revLine.split('\t')[2].split('/')[0]
+                                        coreLine = '%s\t%s\t%s\t%s\t%s\n' % (groupID, 'ncbi' + str(tmp[1].split('|')[1].split('@')[1]), tmp[1], tmp[2].split('/')[0], revFAS)
+                                        finalPhyloprofile.write(coreLine)
+                        else:
                             for fLine in readFile(fasFile):
                                 if refSpec in fLine.split('\t')[0]:
                                     tmp = fLine.split('\t')
@@ -231,8 +245,13 @@ def calcFAS(coreDir, outDir, coreSet, queryID, annoDir, cpus, force):
                                             revFAS = revLine.split('\t')[2].split('/')[0]
                                     coreLine = '%s\t%s\t%s\t%s\t%s\n' % (groupID, 'ncbi' + str(tmp[1].split('|')[1].split('@')[1]), tmp[1], tmp[2].split('/')[0], revFAS)
                                     finalPhyloprofile.write(coreLine)
+                # move domain file
+                if os.path.exists('%s/%s_forward.domains' % (refDir, refSpec)):
+                    for line in readFile('%s/%s_forward.domains' % (refDir, refSpec)):
+                        finalDomain.write(line)
     if not mode == 0:
         finalPhyloprofile.close()
+        finalDomain.close()
     return(missing)
 
 def calcFASall(coreDir, outDir, coreSet, queryID, annoDir, cpus, force, groupRefspec):
@@ -316,14 +335,23 @@ def calcFASall(coreDir, outDir, coreSet, queryID, annoDir, cpus, force, groupRef
             meanCoreFile = '%s/core_orthologs/%s/%s/fas_dir/cutoff_dir/2.cutoff' % (coreDir, coreSet, groupIDmod)
             for tax in readFile(meanCoreFile):
                 if not tax.split('\t')[0] == 'taxa':
-                    if not tax.split('\t')[0] == groupRefspec[groupIDmod]:
+                    if queryID.split('@')[1] == groupRefspec[groupIDmod].split('@')[1]:
+                        if not tax.split('\t')[0] == groupRefspec[groupIDmod]:
+                            ppCore = '%s\t%s\t%s|1\t%s\n' % (groupIDmod, 'ncbi' + str(tax.split('\t')[0].split('@')[1]), tax.split('\t')[2].strip(), tax.split('\t')[1])
+                            finalPhyloprofile.write(ppCore)
+                    else:
                         ppCore = '%s\t%s\t%s|1\t%s\n' % (groupIDmod, 'ncbi' + str(tax.split('\t')[0].split('@')[1]), tax.split('\t')[2].strip(), tax.split('\t')[1])
                         finalPhyloprofile.write(ppCore)
         finalPhyloprofile.close()
         # length phyloprofile file and final fasta file
         for s in SeqIO.parse(mergedFa, 'fasta'):
             idMod = '_'.join(s.id.split('_')[1:])
-            if not idMod.split('|')[1] == groupRefspec[idMod.split('|')[0]]:
+            if queryID.split('@')[1] == groupRefspec[groupIDmod].split('@')[1]:
+                if not idMod.split('|')[1] == groupRefspec[idMod.split('|')[0]]:
+                    finalFa.write('>%s\n%s\n' % (idMod, s.seq))
+                    ppLen = '%s\t%s\t%s\t%s\n' % (idMod.split('|')[0], 'ncbi' + str(idMod.split('|')[1].split('@')[1]), idMod, len(s.seq))
+                    finalLen.write(ppLen)
+            else:
                 finalFa.write('>%s\n%s\n' % (idMod, s.seq))
                 ppLen = '%s\t%s\t%s\t%s\n' % (idMod.split('|')[0], 'ncbi' + str(idMod.split('|')[1].split('@')[1]), idMod, len(s.seq))
                 finalLen.write(ppLen)
@@ -332,12 +360,13 @@ def calcFASall(coreDir, outDir, coreSet, queryID, annoDir, cpus, force, groupRef
         # join domain files
         shutil.copyfileobj(open('%s/%s_all_forward.domains' % (fdogOutDir, queryID), 'rb'), finalFwdDomain)
         finalFwdDomain.close()
-        finalDomain = open('%s/FAS.domains' % (phyloprofileDir), 'w')
+        finalDomain = open('%s/mode1.domains' % (phyloprofileDir), 'w')
         for domains in readFile('%s/FAS_forward.domains' % (phyloprofileDir)):
             tmp = domains.split('\t')
             mGroup = '_'.join(tmp[0].split('#')[0].split('_')[1:])
             mQuery = '_'.join(tmp[0].split('#')[1].split('_')[1:])
             mSeed = '_'.join(tmp[1].split('_')[1:])
+            # if queryID in mSeed:
             domainLine = '%s\t%s\t%s\t%s\t%s\t%s\tNA\tN\n' % (mGroup+'#'+mQuery, mSeed, tmp[2], tmp[3], tmp[4], tmp[5])
             finalDomain.write(domainLine)
         finalDomain.close()
@@ -557,7 +586,7 @@ def searchOrtho(args):
     print('Done! Check output in %s' % fcatOut)
 
 def main():
-    version = '0.0.3'
+    version = '0.0.4'
     parser = argparse.ArgumentParser(description='You are running fcat version ' + str(version) + '.')
     required = parser.add_argument_group('required arguments')
     optional = parser.add_argument_group('optional arguments')
